---
title: Mosaia - The AI community’s platform for creating, sharing and deploying AI agents in a serverless cloud environment - Nov 28, 2024
---

### Speakers: Aaron Wong-Ellis

### Biography of the speakers:

Aaron Wong-Ellis is the co-founder and CTO at Mosaia. His several years of experience in the field of AI, IOT and building enterprise platforms has equipped him with the right skill set to build Mosaia. Aaron has worked as an application architect and engineer for small startups and large Fortune 100 companies like AWS. His recent work focuses on developing a platform for creating, sharing and running LLM agents in a scalable serverless cloud infrastructure.

### Abstract:

Running multiple AI agents reliably on the cloud, can encounter numerous challenges. At Mosaia we faced the challenges head on and created a way to do this in a scalable serverless cloud environment. Allowing people to run their agents with little to no code at all. Just write up your prompts and construct your groups of agents through a browser based UI. Being able to do this, opened up many possibilities to construct and share agents with others to use on Mosaia or run locally using Autogen. Mosaia was created as a platform to not only run agents but allow prompt engineers to host and share these agents with others. Fostering a community of collaboration and creativity around building AI agents.
